@@ -32,9 +32,9 @@ extern "C" {
 #include <sasl/sasl.h>
 }
 
-#include <qregexp.h>
 #include <QSslSocket>
 #include <QUrlQuery>
+#include <QRegularExpression>
 
 #include <KLocalizedString>
 #include <QUrl>
@@ -288,9 +288,8 @@ void kio_sieveProtocol::changeCheck(const QUrl &url)
             query.remove(0, 1);
         }
         QStringList q = query.split(QLatin1Char(','));
-        QStringList::iterator it;
 
-        for (it = q.begin(); it != q.end(); ++it) {
+        for (QStringList::iterator it = q.begin(), end(q.end()); it != end; ++it) {
             if (((*it).section(QLatin1Char('='), 0, 0)).toLower() == QLatin1String("x-mech")) {
                 auth = ((*it).section(QLatin1Char('='), 1)).toUpper();
                 break;
@@ -865,17 +864,17 @@ void kio_sieveProtocol::urlStat(const QUrl &url)
                 if (filename == QString::fromUtf8(r.getKey())) {
                     entry.clear();
 
-                    entry.insert(KIO::UDSEntry::UDS_NAME, QString::fromUtf8(r.getKey()));
+                    entry.fastInsert(KIO::UDSEntry::UDS_NAME, QString::fromUtf8(r.getKey()));
 
-                    entry.insert(KIO::UDSEntry::UDS_FILE_TYPE, S_IFREG);
+                    entry.fastInsert(KIO::UDSEntry::UDS_FILE_TYPE, S_IFREG);
 
                     if (r.getExtra() == "ACTIVE") {
-                        entry.insert(KIO::UDSEntry::UDS_ACCESS, 0700);
+                        entry.fastInsert(KIO::UDSEntry::UDS_ACCESS, 0700);
                     } else {
-                        entry.insert(KIO::UDSEntry::UDS_ACCESS, 0600);
+                        entry.fastInsert(KIO::UDSEntry::UDS_ACCESS, 0600);
                     }
 
-                    entry.insert(KIO::UDSEntry::UDS_MIME_TYPE, QStringLiteral("application/sieve"));
+                    entry.fastInsert(KIO::UDSEntry::UDS_MIME_TYPE, QStringLiteral("application/sieve"));
 
                     //setMetaData("active", (r.getExtra() == "ACTIVE") ? "yes" : "no");
 
@@ -911,17 +910,17 @@ void kio_sieveProtocol::listDir(const QUrl &url)
             }
         } else {
             entry.clear();
-            entry.insert(KIO::UDSEntry::UDS_NAME, QString::fromUtf8(r.getKey()));
+            entry.fastInsert(KIO::UDSEntry::UDS_NAME, QString::fromUtf8(r.getKey()));
 
-            entry.insert(KIO::UDSEntry::UDS_FILE_TYPE, S_IFREG);
+            entry.fastInsert(KIO::UDSEntry::UDS_FILE_TYPE, S_IFREG);
 
             if (r.getExtra() == "ACTIVE") {
-                entry.insert(KIO::UDSEntry::UDS_ACCESS, 0700);// mark exec'able
+                entry.fastInsert(KIO::UDSEntry::UDS_ACCESS, 0700);// mark exec'able
             } else {
-                entry.insert(KIO::UDSEntry::UDS_ACCESS, 0600);
+                entry.fastInsert(KIO::UDSEntry::UDS_ACCESS, 0600);
             }
 
-            entry.insert(KIO::UDSEntry::UDS_MIME_TYPE, QStringLiteral("application/sieve"));
+            entry.fastInsert(KIO::UDSEntry::UDS_MIME_TYPE, QStringLiteral("application/sieve"));
 
             //asetMetaData("active", (r.getExtra() == "ACTIVE") ? "true" : "false");
 
@@ -944,12 +943,14 @@ bool kio_sieveProtocol::saslInteract(void *in, AuthInfo &ai)
     for (; interact->id != SASL_CB_LIST_END; interact++) {
         if (interact->id == SASL_CB_AUTHNAME
             || interact->id == SASL_CB_PASS) {
-            if (m_sUser.isEmpty() || m_sPass.isEmpty()) {
-                if (!openPasswordDialog(ai)) {
+            if (m_sUser.isEmpty() || m_sPass.isEmpty()) {                
+                const int errorCode = openPasswordDialogV2(ai);
+                if (errorCode) {
                     // calling error() below is wrong for two reasons:
                     // - ERR_ABORTED is too harsh
                     // - higher layers already call error() and that can't happen twice.
                     //error(ERR_ABORTED, i18n("No authentication details supplied."));
+                    error(errorCode, QString());
                     return false;
                 }
                 m_sUser = ai.username;
@@ -1289,12 +1290,13 @@ bool kio_sieveProtocol::requestCapabilitiesAfterStartTLS() const
     // Cyrus didn't send CAPABILITIES after STARTTLS until 2.3.11, which is
     // not standard conform, but we need to support that anyway.
     // m_implementation looks like this 'Cyrus timsieved v2.2.12' for Cyrus btw.
-    QRegExp regExp(QStringLiteral("Cyrus\\stimsieved\\sv(\\d+)\\.(\\d+)\\.(\\d+)([-\\w]*)"), Qt::CaseInsensitive);
-    if (regExp.indexIn(m_implementation) >= 0) {
-        const int major = regExp.cap(1).toInt();
-        const int minor = regExp.cap(2).toInt();
-        const int patch = regExp.cap(3).toInt();
-        const QString vendor = regExp.cap(4);
+    QRegularExpression regExp(QStringLiteral("Cyrus\\stimsieved\\sv(\\d+)\\.(\\d+)\\.(\\d+)([-\\w]*)"), QRegularExpression::CaseInsensitiveOption);
+    QRegularExpressionMatch match = regExp.match(m_implementation);
+    if (match.hasMatch()) {
+        const int major = match.captured(1).toInt();
+        const int minor = match.captured(2).toInt();
+        const int patch = match.captured(3).toInt();
+        const QString vendor = match.captured(4);
         if (major < 2 || (major == 2 && (minor < 3 || (minor == 3 && patch < 11))) || (vendor == QLatin1String("-kolab-nocaps"))) {
             ksDebug << " kio_sieveProtocol::requestCapabilitiesAfterStartTLS : Enabling compat mode for Cyrus < 2.3.11 or Cyrus marked as \"kolab-nocaps\"" << endl;
             return true;
