@@ -23,7 +23,6 @@
 #include "kmanagersieve_debug.h"
 
 #include <QThread>
-#include <QUrlQuery>
 #include <QTimer>
 
 #include <KLocalizedString>
@@ -70,7 +69,11 @@ SessionThread::SessionThread(Session *session, QObject *parent)
 
 SessionThread::~SessionThread()
 {
+#if QT_VERSION >= QT_VERSION_CHECK(5, 10, 0)
+    QMetaObject::invokeMethod(this, &SessionThread::doDestroy, Qt::QueuedConnection);
+#else
     QMetaObject::invokeMethod(this, "doDestroy", Qt::QueuedConnection);
+#endif
     if (!thread()->wait(10 * 1000)) {
         thread()->terminate();
         thread()->wait();
@@ -86,7 +89,7 @@ void SessionThread::doInit()
 
     m_socket = new KTcpSocket(this);
     connect(m_socket, &QIODevice::readyRead, this, &SessionThread::slotDataReceived);
-    connect(m_socket, SIGNAL(error(KTcpSocket::Error)), this, SLOT(slotSocketError()));
+    connect(m_socket, QOverload<KTcpSocket::Error>::of(&KTcpSocket::error), this, &SessionThread::slotSocketError);
     connect(m_socket, &KTcpSocket::disconnected, this, &SessionThread::socketDisconnected);
     connect(m_socket, &KTcpSocket::connected, this, &SessionThread::socketConnected);
 }
@@ -106,9 +109,15 @@ void SessionThread::doDestroy()
 // Called in main thread
 void SessionThread::connectToHost(const QUrl &url)
 {
+#if QT_VERSION >= QT_VERSION_CHECK(5, 10, 0)
+    QMetaObject::invokeMethod(this, [this, url]() {
+        doConnectToHost(url);
+    }, Qt::QueuedConnection);
+#else
     QMetaObject::invokeMethod(this, "doConnectToHost",
                               Qt::QueuedConnection,
                               Q_ARG(QUrl, url));
+#endif
 }
 
 // Called in secondary thread
@@ -127,9 +136,15 @@ void SessionThread::doConnectToHost(const QUrl &url)
 // Called in main thread
 void SessionThread::disconnectFromHost(bool sendLogout)
 {
+#if QT_VERSION >= QT_VERSION_CHECK(5, 10, 0)
+    QMetaObject::invokeMethod(this, [this, sendLogout]() {
+        doDisconnectFromHost(sendLogout);
+    }, Qt::QueuedConnection);
+#else
     QMetaObject::invokeMethod(this, "doDisconnectFromHost",
                               Qt::QueuedConnection,
                               Q_ARG(bool, sendLogout));
+#endif
 }
 
 // Called in secondary thread
@@ -146,9 +161,15 @@ void SessionThread::doDisconnectFromHost(bool sendLogout)
 // Called in main thread
 void SessionThread::sendData(const QByteArray &data)
 {
+#if QT_VERSION >= QT_VERSION_CHECK(5, 10, 0)
+    QMetaObject::invokeMethod(this, [this, data]() {
+        doSendData(data);
+    }, Qt::QueuedConnection);
+#else
     QMetaObject::invokeMethod(this, "doSendData",
                               Qt::QueuedConnection,
                               Q_ARG(QByteArray, data));
+#endif
 }
 
 // Called in secondary thread
@@ -220,8 +241,11 @@ void SessionThread::slotSocketError()
 // Called in main thread
 void SessionThread::startAuthentication()
 {
-    QMetaObject::invokeMethod(this, "doStartAuthentication",
-                              Qt::QueuedConnection);
+#if QT_VERSION >= QT_VERSION_CHECK(5, 10, 0)
+    QMetaObject::invokeMethod(this, &SessionThread::doStartAuthentication, Qt::QueuedConnection);
+#else
+    QMetaObject::invokeMethod(this, "doStartAuthentication", Qt::QueuedConnection);
+#endif
 }
 
 // Called in secondary thread
@@ -407,8 +431,11 @@ bool SessionThread::saslClientStep(const QByteArray &challenge)
 // Called in main thread
 void SessionThread::startSsl()
 {
-    QMetaObject::invokeMethod(this, "doStartSsl",
-                              Qt::QueuedConnection);
+#if QT_VERSION >= QT_VERSION_CHECK(5, 10, 0)
+    QMetaObject::invokeMethod(this, &SessionThread::doStartSsl, Qt::QueuedConnection);
+#else
+    QMetaObject::invokeMethod(this, "doStartSsl", Qt::QueuedConnection);
+#endif
 }
 
 // Called in secondary thread
