@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -21,17 +21,16 @@
 
 #include <QToolButton>
 
-namespace KSieveUi
-{
+namespace KSieveUi {
 class SieveHelpButton : public QToolButton
 {
     Q_OBJECT
 public:
     explicit SieveHelpButton(QWidget *parent = nullptr);
-    ~SieveHelpButton();
+    ~SieveHelpButton() override;
 
 protected:
-    bool event(QEvent *event) Q_DECL_OVERRIDE;
+    bool event(QEvent *event) override;
 };
 }
 
