@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -26,7 +26,7 @@
 
 #include <QHBoxLayout>
 #include <QLabel>
-#include <QDomNode>
+#include <QXmlStreamReader>
 #include "libksieve_debug.h"
 
 using namespace KSieveUi;
@@ -67,45 +67,43 @@ QWidget *SieveActionNotify::createParamWidget(QWidget *parent) const
     return w;
 }
 
-bool SieveActionNotify::setParamWidgetValue(const QDomElement &element, QWidget *w, QString &error)
+bool SieveActionNotify::setParamWidgetValue(QXmlStreamReader &element, QWidget *w, QString &error)
 {
-    QDomNode node = element.firstChild();
-    while (!node.isNull()) {
-        QDomElement e = node.toElement();
-        if (!e.isNull()) {
-            const QString tagName = e.tagName();
-            if (tagName == QLatin1String("tag")) {
-                const QString tagValue = e.text();
-                if (tagValue == QLatin1String("message")) {
-                    const QString strValue = AutoCreateScriptUtil::strValue(node);
-                    if (!strValue.isEmpty()) {
-                        QLineEdit *message = w->findChild<QLineEdit *>(QStringLiteral("message"));
-                        message->setText(AutoCreateScriptUtil::quoteStr(strValue));
-                    }
-                } else if (tagValue == QLatin1String("importance")) {
-                    const QString strValue = AutoCreateScriptUtil::strValue(node);
-                    if (!strValue.isEmpty()) {
-                        SelectImportanceCombobox *importance = w->findChild<SelectImportanceCombobox *>(QStringLiteral("importancecombo"));
-                        importance->setCode(strValue, name(), error);
-                    }
-                } else {
-                    unknowTagValue(tagValue, error);
-                    qCDebug(LIBKSIEVE_LOG) << " SieveActionNotify::setParamWidgetValue unknown tagValue" << tagValue;
+    while (element.readNextStartElement()) {
+        const QStringRef tagName = element.name();
+        if (tagName == QLatin1String("tag")) {
+            const QString tagValue = element.readElementText();
+            if (tagValue == QLatin1String("message")) {
+                const QString strValue = AutoCreateScriptUtil::strValue(element);
+                if (!strValue.isEmpty()) {
+                    QLineEdit *message = w->findChild<QLineEdit *>(QStringLiteral("message"));
+                    message->setText(AutoCreateScriptUtil::quoteStr(strValue));
+                }
+            } else if (tagValue == QLatin1String("importance")) {
+                const QString strValue = AutoCreateScriptUtil::strValue(element);
+                if (!strValue.isEmpty()) {
+                    SelectImportanceCombobox *importance = w->findChild<SelectImportanceCombobox *>(QStringLiteral("importancecombo"));
+                    importance->setCode(strValue, name(), error);
                 }
-            } else if (tagName == QLatin1String("crlf")) {
-                //nothing
-            } else if (tagName == QLatin1String("comment")) {
-                //implement in the future ?
-            } else if (tagName == QLatin1String("str")) {
-                QLineEdit *method = w->findChild<QLineEdit *>(QStringLiteral("method"));
-                method->setText(AutoCreateScriptUtil::quoteStr(e.text()));
             } else {
-                unknownTag(tagName, error);
-                qCDebug(LIBKSIEVE_LOG) << " SieveActionNotify::setParamWidgetValue unknown tagName " << tagName;
+                unknowTagValue(tagValue, error);
+                qCDebug(LIBKSIEVE_LOG) << " SieveActionNotify::setParamWidgetValue unknown tagValue" << tagValue;
             }
+        } else if (tagName == QLatin1String("crlf")) {
+            element.skipCurrentElement();
+            //nothing
+        } else if (tagName == QLatin1String("comment")) {
+            element.skipCurrentElement();
+            //implement in the future ?
+        } else if (tagName == QLatin1String("str")) {
+            QLineEdit *method = w->findChild<QLineEdit *>(QStringLiteral("method"));
+            method->setText(AutoCreateScriptUtil::quoteStr(element.readElementText()));
+        } else {
+            unknownTag(tagName, error);
+            qCDebug(LIBKSIEVE_LOG) << " SieveActionNotify::setParamWidgetValue unknown tagName " << tagName;
         }
-        node = node.nextSibling();
     }
+
     return true;
 }
 
@@ -157,4 +155,3 @@ QUrl SieveActionNotify::href() const
 {
     return SieveEditorUtil::helpUrl(SieveEditorUtil::strToVariableName(name()));
 }
-
