@@ -27,13 +27,13 @@ class SieveActionRedirect : public SieveAction
     Q_OBJECT
 public:
     explicit SieveActionRedirect(SieveEditorGraphicalModeWidget *sieveGraphicalModeWidget, QObject *parent = nullptr);
-    QWidget *createParamWidget(QWidget *parent) const override;
-    QString code(QWidget *) const override;
-    QStringList needRequires(QWidget *parent) const override;
-    bool setParamWidgetValue(QXmlStreamReader &element, QWidget *parent, QString &error) override;
-    QString help() const override;
+    Q_REQUIRED_RESULT QWidget *createParamWidget(QWidget *parent) const override;
+    Q_REQUIRED_RESULT QString code(QWidget *) const override;
+    Q_REQUIRED_RESULT QStringList needRequires(QWidget *parent) const override;
+    Q_REQUIRED_RESULT bool setParamWidgetValue(QXmlStreamReader &element, QWidget *parent, QString &error) override;
+    Q_REQUIRED_RESULT QString help() const override;
 
-    QUrl href() const override;
+    Q_REQUIRED_RESULT QUrl href() const override;
 private:
     bool mHasCopySupport = false;
     bool mHasListSupport = false;
