@@ -43,7 +43,7 @@ public:
     ~SieveConditionWidget();
 
     void updateAddRemoveButton(bool addButtonEnabled, bool removeButtonEnabled);
-    void generatedScript(QString &script, QStringList &requires, bool inForEveryPartLoop);
+    void generatedScript(QString &script, QStringList &required, bool inForEveryPartLoop);
     void setCondition(const QString &conditionName, QXmlStreamReader &element, bool notCondition, QString &error);
     void clear();
 
@@ -77,7 +77,7 @@ public:
     explicit SieveConditionWidgetLister(SieveEditorGraphicalModeWidget *sieveGraphicalModeWidget, QWidget *parent = nullptr);
     ~SieveConditionWidgetLister();
 
-    void generatedScript(QString &script, int &numberOfCondition, QStringList &requires, bool inForEveryPartLoop);
+    void generatedScript(QString &script, int &numberOfCondition, QStringList &requireModules, bool inForEveryPartLoop);
     int conditionNumber() const;
     void loadScript(QXmlStreamReader &element, bool uniqTest, bool notCondition, QString &error);
 
